atomate.vasp.firetasks.tests package — atomate 0.9.2 documentation

# atomate.vasp.firetasks.tests package

## Submodules

## atomate.vasp.firetasks.tests.test_copy module

class `atomate.vasp.firetasks.tests.test_copy.` `TestCopyVaspOutputs`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_gzip_copy`()
  `test_plain_copy`()
  `test_plain_copy_more`()
  `test_relax2_copy`()
  `test_unittestsetup`()

## atomate.vasp.firetasks.tests.test_get_interpolated_poscar module

class `atomate.vasp.firetasks.tests.test_get_interpolated_poscar.` `TestGetInterpolatedPOSCAR`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_getinterpolatedposcar`()

## atomate.vasp.firetasks.tests.test_polarization_to_db module

class `atomate.vasp.firetasks.tests.test_polarization_to_db.` `TestFerroelectricWorkflow`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_polarizationtodb`()

## atomate.vasp.firetasks.tests.test_write_vasp module

class `atomate.vasp.firetasks.tests.test_write_vasp.` `TestWriteVasp`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`()

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_ioset_explicit`()
  `test_ioset_implicit`()
  `test_ioset_params`()
  `test_modify_incar`()
  `test_modify_potcar`()
  `test_pmgobjects`()

## atomate.vasp.firetasks.tests.test_write_vasp_from_interpolated_poscar module

class `atomate.vasp.firetasks.tests.test_write_vasp_from_interpolated_poscar.` `TestWriteVaspFromInterpolatedPOSCAR`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_writevaspfrominterpolatedposcar`()

## Module contents